@@ -1,3 +1,4 @@
+import copy
 import inspect
 from typing import Any, Awaitable, Callable, ParamSpec, TypeVar
 
@@ -47,12 +48,28 @@ class SecureRouter(APIRouter):
             context_acl_provider,
         )
 
+        kwargs = self._propagate_params(handler, kwargs, request, context)
         output = handler(*args, **kwargs)
         if inspect.iscoroutine(output):
             output = await output
 
         return output
 
+    @staticmethod
+    def _propagate_params(
+        func: Callable[P, Awaitable[T] | T],
+        kwargs: [str, Any],
+        request: Request,
+        context: Any | None,
+    ) -> dict[str, Any]:
+        new_kwargs = copy.copy(kwargs)
+        func_signature = inspect.signature(func)
+        if func_signature.parameters.get("context"):
+            new_kwargs["context"] = context
+        if func_signature.parameters.get("request"):
+            new_kwargs["request"] = request
+        return new_kwargs
+
     def post(self, *outer_args, **outer_kwargs):
         return lambda func: self._http_method(func, "post", *outer_args, **outer_kwargs)
 
